@@ -1631,8 +1631,7 @@ def _serve_application(
 
 def start_visualization(image_path: Text, port: int) -> None:
     """Add routes to serve the conversation visualization files."""
-
-    app = Sanic(__name__)
+    app = Sanic(__name__, register=False)
 
     # noinspection PyUnusedLocal
     @app.exception(NotFound)
