@@ -14,7 +14,6 @@ from rasa.nlu.config import RasaNLUModelConfig
 from rasa.nlu.constants import (
     TOKENS_NAMES,
     FEATURIZER_CLASS_ALIAS,
-    MIN_ADDITIONAL_REGEX_PATTERNS,
 )
 from rasa.shared.nlu.constants import (
     TEXT,
@@ -29,7 +28,6 @@ from rasa.nlu.model import Metadata
 from rasa.nlu.tokenizers.tokenizer import Tokenizer
 from rasa.shared.nlu.training_data.training_data import TrainingData
 from rasa.shared.nlu.training_data.message import Message
-from rasa.shared.utils.common import lazy_property
 
 logger = logging.getLogger(__name__)
 
@@ -46,18 +44,17 @@ class RegexFeaturizer(SparseFeaturizer):
         "use_lookup_tables": True,
         # use regexes to generate features
         "use_regexes": True,
+        # use match word boundaries for lookup table
+        "use_word_boundaries": True,
         # Additional number of patterns to consider
         # for incremental training
         "number_additional_patterns": None,
-        # use match word boundaries for lookup table
-        "use_word_boundaries": True,
     }
 
     def __init__(
         self,
         component_config: Optional[Dict[Text, Any]] = None,
         known_patterns: Optional[List[Dict[Text, Text]]] = None,
-        pattern_vocabulary_stats: Optional[Dict[Text, int]] = None,
         finetune_mode: bool = False,
     ) -> None:
         """Constructs new features for regexes and lookup table using regex expressions.
@@ -65,64 +62,34 @@ class RegexFeaturizer(SparseFeaturizer):
         Args:
             component_config: Configuration for the component
             known_patterns: Regex Patterns the component should pre-load itself with.
-            pattern_vocabulary_stats: Statistics about number of pattern slots filled
-                and total number available.
             finetune_mode: Load component in finetune mode.
         """
         super().__init__(component_config)
 
         self.known_patterns = known_patterns if known_patterns else []
         self.case_sensitive = self.component_config["case_sensitive"]
-        self.number_additional_patterns = self.component_config[
-            "number_additional_patterns"
-        ]
         self.finetune_mode = finetune_mode
-        self.pattern_vocabulary_stats = pattern_vocabulary_stats
-
-        if self.finetune_mode and not self.pattern_vocabulary_stats:
-            # If the featurizer is instantiated in finetune mode,
-            # the vocabulary stats for it should be known.
-            raise rasa.shared.exceptions.InvalidParameterException(
-                f"{self.__class__.__name__} was instantiated with"
-                f" `finetune_mode=True` but `pattern_vocabulary_stats`"
-                f" was left to `None`. This is invalid since the featurizer"
-                f" needs vocabulary statistics to featurize in finetune mode."
+        if self.component_config["number_additional_patterns"]:
+            rasa.shared.utils.io.raise_deprecation_warning(
+                "The parameter `number_additional_patterns` has been deprecated "
+                "since the pipeline does not create an extra buffer for new vocabulary "
+                "anymore. Any value assigned to this parameter will be ignored. "
+                "You can omit specifying `number_additional_patterns` in future runs."
             )
 
-    @lazy_property
-    def vocabulary_stats(self) -> Dict[Text, int]:
-        """Computes total vocabulary size and how much of it is consumed.
-
-        Returns:
-            Computed vocabulary size and number of filled vocabulary slots.
-        """
-        if not self.finetune_mode:
-            max_number_patterns = (
-                len(self.known_patterns) + self._get_num_additional_slots()
-            )
-            return {
-                "pattern_slots_filled": len(self.known_patterns),
-                "max_number_patterns": max_number_patterns,
-            }
-        else:
-            self.pattern_vocabulary_stats["pattern_slots_filled"] = len(
-                self.known_patterns
-            )
-            return self.pattern_vocabulary_stats
-
     def _merge_new_patterns(self, new_patterns: List[Dict[Text, Text]]) -> None:
         """Updates already known patterns with new patterns extracted from data.
 
+        New patterns should always be added to the end of the existing
+        patterns and the order of the existing patterns should not be disturbed.
+
         Args:
             new_patterns: Patterns extracted from training data and to be merged with
                 known patterns.
         """
-        max_number_patterns = self.pattern_vocabulary_stats["max_number_patterns"]
         pattern_name_index_map = {
             pattern["name"]: index for index, pattern in enumerate(self.known_patterns)
         }
-        patterns_dropped = False
-
         for extra_pattern in new_patterns:
             new_pattern_name = extra_pattern["name"]
 
@@ -133,35 +100,7 @@ class RegexFeaturizer(SparseFeaturizer):
                     "pattern"
                 ] = extra_pattern["pattern"]
             else:
-                if len(self.known_patterns) == max_number_patterns:
-                    patterns_dropped = True
-                    continue
                 self.known_patterns.append(extra_pattern)
-        if patterns_dropped:
-            rasa.shared.utils.io.raise_warning(
-                f"The originally trained model was configured to "
-                f"handle a maximum number of {max_number_patterns} patterns. "
-                f"The current training data exceeds this number as "
-                f"there are {len(new_patterns)} patterns in total. "
-                f"Some patterns will be dropped and not used for "
-                f"featurization. It is advisable to re-train the "
-                f"model from scratch."
-            )
-
-    def _get_num_additional_slots(self) -> int:
-        """Computes number of additional pattern slots available."""
-        if self.number_additional_patterns is None:
-            # We take twice the number of currently defined
-            # regex patterns as the number of additional
-            # vocabulary slots to support if this parameter
-            # is not configured by the user. Also, to avoid having
-            # to retrain from scratch very often, the default number
-            # of additional slots is kept to MIN_ADDITIONAL_SLOTS.
-            # This is an empirically tuned number.
-            self.number_additional_patterns = max(
-                MIN_ADDITIONAL_REGEX_PATTERNS, len(self.known_patterns) * 2
-            )
-        return self.number_additional_patterns
 
     def train(
         self,
@@ -259,10 +198,10 @@ class RegexFeaturizer(SparseFeaturizer):
 
         sequence_length = len(tokens)
 
-        max_number_patterns = self.vocabulary_stats["max_number_patterns"]
+        num_patterns = len(self.known_patterns)
 
-        sequence_features = np.zeros([sequence_length, max_number_patterns])
-        sentence_features = np.zeros([1, max_number_patterns])
+        sequence_features = np.zeros([sequence_length, num_patterns])
+        sentence_features = np.zeros([1, num_patterns])
 
         for pattern_index, pattern in enumerate(self.known_patterns):
             matches = re.finditer(
@@ -283,7 +222,6 @@ class RegexFeaturizer(SparseFeaturizer):
                             sentence_features[0][pattern_index] = 1.0
 
                 t.set("pattern", patterns)
-
         return (
             scipy.sparse.coo_matrix(sequence_features),
             scipy.sparse.coo_matrix(sentence_features),
@@ -314,24 +252,12 @@ class RegexFeaturizer(SparseFeaturizer):
 
         patterns_file_name = Path(model_dir) / (file_name + ".patterns.pkl")
 
-        vocabulary_stats_file_name = Path(model_dir) / (
-            file_name + ".vocabulary_stats.pkl"
-        )
-
         known_patterns = None
-        vocabulary_stats = None
         if patterns_file_name.exists():
             known_patterns = rasa.shared.utils.io.read_json_file(patterns_file_name)
-        if vocabulary_stats_file_name.exists():
-            vocabulary_stats = rasa.shared.utils.io.read_json_file(
-                vocabulary_stats_file_name
-            )
 
         return RegexFeaturizer(
-            meta,
-            known_patterns=known_patterns,
-            pattern_vocabulary_stats=vocabulary_stats,
-            finetune_mode=should_finetune,
+            meta, known_patterns=known_patterns, finetune_mode=should_finetune,
         )
 
     def persist(self, file_name: Text, model_dir: Text) -> Optional[Dict[Text, Any]]:
@@ -347,8 +273,5 @@ class RegexFeaturizer(SparseFeaturizer):
         patterns_file_name = file_name + ".patterns.pkl"
         regex_file = Path(model_dir) / patterns_file_name
         utils.write_json_to_file(regex_file, self.known_patterns, indent=4)
-        vocabulary_stats_file_name = file_name + ".vocabulary_stats.pkl"
-        vocabulary_file = Path(model_dir) / vocabulary_stats_file_name
-        utils.write_json_to_file(vocabulary_file, self.vocabulary_stats, indent=4)
 
         return {"file": file_name}
