@@ -94,3 +94,5 @@ DIAGNOSTIC_DATA = "diagnostic_data"
 
 RESPONSE_CONDITION = "condition"
 CHANNEL = "channel"
+DEFAULT_YAML_SEQUENCE_INDENT_ENV_VAR = "DEFAULT_YAML_SEQUENCE_INDENT"
+DEFAULT_YAML_SEQUENCE_INDENT = 2
