@@ -3,8 +3,8 @@ from typing import List, Optional, Text, Tuple, Callable, Union, Any
 import tensorflow as tf
 import tensorflow_addons as tfa
 import rasa.utils.tensorflow.crf
-from tensorflow.python.keras.utils import tf_utils
-from tensorflow.python.keras import backend as K
+from tensorflow.python.layers.utils import smart_cond
+from tensorflow.keras import backend as K
 from rasa.utils.tensorflow.constants import (
     SOFTMAX,
     MARGIN,
@@ -88,9 +88,7 @@ class SparseDropout(tf.keras.layers.Dropout):
             to_retain = tf.greater_equal(to_retain_prob, self.rate)
             return tf.sparse.retain(inputs, to_retain)
 
-        outputs = tf_utils.smart_cond(
-            training, dropped_inputs, lambda: tf.identity(inputs)
-        )
+        outputs = smart_cond(training, dropped_inputs, lambda: tf.identity(inputs))
         # need to explicitly recreate sparse tensor, because otherwise the shape
         # information will be lost after `retain`
         # noinspection PyProtectedMember
@@ -415,7 +413,7 @@ class Ffnn(tf.keras.layers.Layer):
                 RandomlyConnectedDense(
                     units=layer_size,
                     density=density,
-                    activation=tfa.activations.gelu,
+                    activation=tf.nn.gelu,
                     kernel_regularizer=l2_regularizer,
                     name=f"hidden_layer_{layer_name_suffix}_{i}",
                 )
@@ -425,6 +423,7 @@ class Ffnn(tf.keras.layers.Layer):
     def call(
         self, x: tf.Tensor, training: Optional[Union[tf.Tensor, bool]] = None
     ) -> tf.Tensor:
+        """Apply feed-forward network layer."""
         for layer in self._ffn_layers:
             x = layer(x, training=training)
 
@@ -557,7 +556,7 @@ class InputMask(tf.keras.layers.Layer):
             return tf.where(tf.tile(lm_mask_bool, (1, 1, x.shape[-1])), x_other, x)
 
         return (
-            tf_utils.smart_cond(training, x_masked, lambda: tf.identity(x)),
+            smart_cond(training, x_masked, lambda: tf.identity(x)),
             lm_mask_bool,
         )
 
@@ -571,7 +570,6 @@ def _scale_loss(log_likelihood: tf.Tensor) -> tf.Tensor:
     Returns:
         Scaling tensor.
     """
-
     p = tf.math.exp(log_likelihood)
     # only scale loss if some examples are already learned
     return tf.cond(
