@@ -1,8 +1,7 @@
 from typing import Optional, Text, Tuple, Union
 import tensorflow as tf
-import tensorflow_addons as tfa
-from tensorflow.python.keras.utils import tf_utils
-from tensorflow.python.keras import backend as K
+from tensorflow.python.layers.utils import smart_cond
+from tensorflow.keras import backend as K
 import numpy as np
 from rasa.utils.tensorflow.layers import RandomlyConnectedDense
 
@@ -253,7 +252,7 @@ class MultiHeadAttention(tf.keras.layers.Layer):
 
             return logits + drop_mask * -1e9
 
-        return tf_utils.smart_cond(training, droped_logits, lambda: tf.identity(logits))
+        return smart_cond(training, droped_logits, lambda: tf.identity(logits))
 
     def _scaled_dot_product_attention(
         self,
@@ -436,7 +435,7 @@ class TransformerEncoderLayer(tf.keras.layers.Layer):
         self._ffn_layers = [
             tf.keras.layers.LayerNormalization(epsilon=1e-6),
             RandomlyConnectedDense(
-                units=filter_units, activation=tfa.activations.gelu, density=density
+                units=filter_units, activation=tf.nn.gelu, density=density
             ),  # (batch_size, length, filter_units)
             tf.keras.layers.Dropout(dropout_rate),
             RandomlyConnectedDense(
